@@ -1,6 +1,7 @@
 package Carton::Util;
 use strict;
 use warnings;
+use version; our $VERSION = version->declare("v0.9.12");
 
 sub load_json {
     my $file = shift;
@@ -13,6 +14,7 @@ sub dump_json {
     my($data, $file) = @_;
 
     open my $fh, ">", $file or die "$file: $!";
+    binmode $fh;
     print $fh to_json($data);
 }
 
